jQuery(document).ready(function($) {
	// Automatically hide dismissible notices after 5 seconds
	setTimeout(function () {
		$('.notice.is-dismissible').fadeOut();
	}, 5000);

	// Freeze the page (max 5sec)
	function freezePage() {
		$('.wrap').addClass('page-frozen').append('<div class="spinner is-active"></div>');
		setTimeout(function() {
			$('.spinner').remove();
			$('.wrap').removeClass('page-frozen');
		}, 2500);
	}

	// Handle bulk actions
	$('#doaction').on('click', handleBulkAction);
	function handleBulkAction(e) {
		var bulkAction = $('#bulk-action-selector-top').val();
		if (bulkAction === 'delete-selected') {
			// Count only the selected checkboxes in the table
			var selectedCount = $('#bulk-action-form input[name="checked[]"]:checked').length;
			// Get the confirmation message
			var deleteMessage = getDeleteConfirmationMessage(selectedCount);
			// If the user cancels the confirmation, prevent the action
			if (!confirm(deleteMessage)) {
				e.preventDefault();
				return;
			}
		}
		freezePage();
	}

	// Generate the delete confirmation message based on the number of selected items
	function getDeleteConfirmationMessage(selectedCount) {
		// Count only the checkboxes related to the plugins (excluding "Select All")
		var totalCount = $('#bulk-action-form input[name="checked[]"]').length;
		// If one plugin is selected
		if (selectedCount === 1) {
			return muPluginL10n.deleteConfirmation;
		// If all plugins are selected
		} else if (selectedCount === totalCount) {
			return muPluginL10n.bulkDeleteAllConfirm.replace('%s', selectedCount);
		// If more than one plugin is selected
		} else if (selectedCount > 1) {
			return muPluginL10n.bulkDeleteMultipleConfirm.replace('%s', selectedCount);
		}
	}

	// Handle the delete link click event with confirmation
	$('.actions-container').on('click', 'a', function(event) {		
		if ($(this).hasClass('delete-link')) {
			event.preventDefault(); // Prevent default link behavior
			if (confirm(muPluginL10n.deleteConfirmation)) {
				freezePage(); // Freeze the page
				window.location.href = $(this).attr('href'); // Redirect to the link's URL
			}
		} else {
			freezePage(); // Just Freeze for other links
		}
	});

	// Toggle the "Apply" button state
	toggleApplyButton(); // Initial call to set the correct state of the "Apply" buttons
	$('.bulkactions > select').prop('disabled', false); // Enable the select element inside the .bulkactions div
	$('#bulk-action-selector-top, #bulk-action-selector-bottom, #bulk-action-form input[type="checkbox"]').on('change', toggleApplyButton);
	function toggleApplyButton() {
		var actionSelectedTop = $('#bulk-action-selector-top').val() !== "-1";
		var actionSelectedBottom = $('#bulk-action-selector-bottom').val() !== "-1";
		var checkboxSelected = $('#bulk-action-form input[type="checkbox"]:checked').length > 0;
		$('#doaction, #doaction2').prop('disabled', !((actionSelectedTop || actionSelectedBottom) && checkboxSelected));
	}
});
